summaryrefslogtreecommitdiffstats
path: root/libswresample
diff options
context:
space:
mode:
authorTimothy Gu <timothygu99@gmail.com>2013-06-28 17:24:26 -0700
committerMichael Niedermayer <michaelni@gmx.at>2013-06-29 02:31:16 +0200
commita9bbf59be73264ed63b08b67024cd04720dd1f43 (patch)
tree6f849d011c7a7b801b42dba60358cb5fae185398 /libswresample
parentfc736a99eae194c85fe344a4db895c1cd3493d45 (diff)
downloadffmpeg-streaming-a9bbf59be73264ed63b08b67024cd04720dd1f43.zip
ffmpeg-streaming-a9bbf59be73264ed63b08b67024cd04720dd1f43.tar.gz
cosmetics: Fix "dont" "wont" "doesnt" typos
Signed-off-by: Michael Niedermayer <michaelni@gmx.at>
Diffstat (limited to 'libswresample')
-rw-r--r--libswresample/swresample.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libswresample/swresample.c b/libswresample/swresample.c
index 08b1aad..ba2afdb 100644
--- a/libswresample/swresample.c
+++ b/libswresample/swresample.c
@@ -727,7 +727,7 @@ static int swr_convert_internal(struct SwrContext *s, AudioData *out, int out_co
}
s->dither.noise_pos += out_count;
}
//FIXME packed doesnt need more than 1 chan here!
swri_audio_convert(s->out_convert, out, conv_src, out_count);
}
return out_count;
@@ -747,7 +747,7 @@ int swr_convert(struct SwrContext *s, uint8_t *out_arg[SWR_CH_MAX], int out_coun
reversefill_audiodata(&s->drop_temp, tmp_arg);
s->drop_output *= -1; //FIXME find a less hackish solution
- ret = swr_convert(s, tmp_arg, FFMIN(-s->drop_output, MAX_DROP_STEP), in_arg, in_count); //FIXME optimize but this is as good as never called so maybe it doesnt matter
+ ret = swr_convert(s, tmp_arg, FFMIN(-s->drop_output, MAX_DROP_STEP), in_arg, in_count); //FIXME optimize but this is as good as never called so maybe it doesn't matter
s->drop_output *= -1;
in_count = 0;
if(ret>0) {
@@ -727,7 +727,7 @@ static int swr_convert_internal(struct SwrContext *s, AudioData *out, int out_co
s->dither.noise_pos += out_count;
}
-//FIXME packed doesnt need more than 1 chan here!
+//FIXME packed doesn't need more than 1 chan here!
swri_audio_convert(s->out_convert, out, conv_src, out_count);
}
OpenPOWER on IntegriCloud